@@ -1,8 +1,11 @@
 import logging
 import os
 import shutil
+from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import Callable, Generator, Set
+from typing import Callable, Iterable, Set
+
+from tempren.path_generator import File
 
 FileRenamerType = Callable[[Path, Path, bool], None]
 
@@ -18,27 +21,51 @@ class DestinationAlreadyExistsError(FileExistsError):
         )
 
 
-class FileGatherer:
-    start_directory: Path
-    glob_pattern: str  # TODO: globbing should be done at the filtering stage
-    # TODO: add an option to include hidden files
+class FileGatherer(ABC):
+    include_hidden: bool = False
+    """Include hidden files and directories when making the search"""
 
-    def __init__(self, directory_path: Path, glob_pattern: str = "*"):
-        self.start_directory = directory_path
-        self.glob_pattern = glob_pattern
+    @abstractmethod
+    def gather_in(self, start_directory: Path) -> Iterable[File]:
+        raise NotImplementedError()
 
-    def __iter__(self) -> Generator[Path, None, None]:
-        def is_hidden(path: Path) -> bool:
-            return path.name.startswith(".")
 
-        # os.chdir(self.start_directory)  # FIXME: implement
+class FilesystemGatherer(FileGatherer, ABC):
+    def _include_path_in_result(self, path: Path) -> bool:
+        if not self.include_hidden:
+            return not path.name.startswith(".")
+        return True
 
-        yield from filter(
-            lambda p: not p.is_dir() and not is_hidden(p),
-            self.start_directory.rglob(self.glob_pattern),
+
+class FlatFileGatherer(FilesystemGatherer):
+    def gather_in(self, start_directory: Path) -> Iterable[File]:
+        yield from map(
+            lambda file_path: File(
+                start_directory, file_path.relative_to(start_directory)
+            ),
+            filter(
+                lambda file_path: self._include_path_in_result(file_path)
+                and not file_path.is_dir(),
+                start_directory.glob("*"),
+            ),
         )
 
 
+class RecursiveFileGatherer(FilesystemGatherer):
+    def gather_in(self, start_directory: Path) -> Iterable[File]:
+        yield from self._gather_in(start_directory, start_directory)
+
+    def _gather_in(self, directory: Path, start_directory: Path) -> Iterable[File]:
+        for dir_entry in directory.iterdir():
+            if not self._include_path_in_result(dir_entry):
+                continue
+
+            if dir_entry.is_dir():
+                yield from self._gather_in(dir_entry, start_directory)
+            else:
+                yield File(start_directory, dir_entry.relative_to(start_directory))
+
+
 class FileRenamer:
     def __call__(
         self,
@@ -121,8 +148,9 @@ class PrintingRenamerWrapper:
             self.log.debug("Trying to rename: %s to %s", source_path, destination_path)
         self.renamer(source_path, destination_path, override)
 
-        self.log.info(f"\nRenamed: {source_path}")
+        self.log.info(f"Renamed: {source_path}")
         if override:
-            self.log.info(f"     to: {destination_path} (override)")
+            self.log.info(f"         to: {destination_path} (override)")
+            # self.log.info(f"to existing: {destination_path} (override)")
         else:
             self.log.info(f"     to: {destination_path}")
